# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/permission_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)fsai_grpc_api/protos/permission_api.proto\x1a fsai_grpc_api/protos/utils.proto\"7\n\nPermission\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0f\n\x07role_id\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\"@\n\x1d\x46indOrCreatePermissionRequest\x12\x1f\n\npermission\x18\x01 \x01(\x0b\x32\x0b.Permission\"c\n\x1e\x46indOrCreatePermissionResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1f\n\npermission\x18\x02 \x01(\x0b\x32\x0b.Permission\"9\n\x16ListPermissionsRequest\x12\x1f\n\npermission\x18\x01 \x01(\x0b\x32\x0b.Permission\"]\n\x17ListPermissionsResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12 \n\x0bpermissions\x18\x02 \x03(\x0b\x32\x0b.Permission2\xb0\x01\n\rPermissionApi\x12Y\n\x16\x46indOrCreatePermission\x12\x1e.FindOrCreatePermissionRequest\x1a\x1f.FindOrCreatePermissionResponse\x12\x44\n\x0fListPermissions\x12\x17.ListPermissionsRequest\x1a\x18.ListPermissionsResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fsai_grpc_api.protos.permission_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PERMISSION._serialized_start=79
  _PERMISSION._serialized_end=134
  _FINDORCREATEPERMISSIONREQUEST._serialized_start=136
  _FINDORCREATEPERMISSIONREQUEST._serialized_end=200
  _FINDORCREATEPERMISSIONRESPONSE._serialized_start=202
  _FINDORCREATEPERMISSIONRESPONSE._serialized_end=301
  _LISTPERMISSIONSREQUEST._serialized_start=303
  _LISTPERMISSIONSREQUEST._serialized_end=360
  _LISTPERMISSIONSRESPONSE._serialized_start=362
  _LISTPERMISSIONSRESPONSE._serialized_end=455
  _PERMISSIONAPI._serialized_start=458
  _PERMISSIONAPI._serialized_end=634
# @@protoc_insertion_point(module_scope)
