# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/workflow_analyzer_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0fsai_grpc_api/protos/workflow_analyzer_api.proto\"M\n GetEstimatesByTotalAoiKm2Request\x12\x15\n\rtotal_aoi_km2\x18\x01 \x01(\x05\x12\x12\n\nbatch_size\x18\x02 \x01(\x05\"L\n GetEstimatesByTotalImagesRequest\x12\x14\n\x0ctotal_images\x18\x01 \x01(\x05\x12\x12\n\nbatch_size\x18\x02 \x01(\x05\"4\n\x1eGetEstimatesByMissionIdRequest\x12\x12\n\nmission_id\x18\x01 \x01(\x05\"v\n\x14WorkflowAnalyzerCost\x12\x1b\n\x13\x66\x65\x61ture_acquisition\x18\x01 \x01(\x02\x12\x19\n\x11image_acquisition\x18\x02 \x01(\x02\x12\x17\n\x0fimage_inference\x18\x03 \x01(\x02\x12\r\n\x05total\x18\x04 \x01(\x02\"w\n\x15WorkflowAnalyzerHours\x12\x1b\n\x13\x66\x65\x61ture_acquisition\x18\x01 \x01(\x02\x12\x19\n\x11image_acquisition\x18\x02 \x01(\x02\x12\x17\n\x0fimage_inference\x18\x03 \x01(\x02\x12\r\n\x05total\x18\x04 \x01(\x02\"|\n\x18WorkflowAnalyzerResponse\x12\x14\n\x0c\x62\x61tch_number\x18\x01 \x01(\x05\x12#\n\x04\x63ost\x18\x05 \x01(\x0b\x32\x15.WorkflowAnalyzerCost\x12%\n\x05hours\x18\x06 \x01(\x0b\x32\x16.WorkflowAnalyzerHours2\xa2\x02\n\x13WorkflowAnalyzerApi\x12Y\n\x19GetEstimatesByTotalAoiKm2\x12!.GetEstimatesByTotalAoiKm2Request\x1a\x19.WorkflowAnalyzerResponse\x12Y\n\x19GetEstimatesByTotalImages\x12!.GetEstimatesByTotalImagesRequest\x1a\x19.WorkflowAnalyzerResponse\x12U\n\x17GetEstimatesByMissionId\x12\x1f.GetEstimatesByMissionIdRequest\x1a\x19.WorkflowAnalyzerResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fsai_grpc_api.protos.workflow_analyzer_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETESTIMATESBYTOTALAOIKM2REQUEST._serialized_start=52
  _GETESTIMATESBYTOTALAOIKM2REQUEST._serialized_end=129
  _GETESTIMATESBYTOTALIMAGESREQUEST._serialized_start=131
  _GETESTIMATESBYTOTALIMAGESREQUEST._serialized_end=207
  _GETESTIMATESBYMISSIONIDREQUEST._serialized_start=209
  _GETESTIMATESBYMISSIONIDREQUEST._serialized_end=261
  _WORKFLOWANALYZERCOST._serialized_start=263
  _WORKFLOWANALYZERCOST._serialized_end=381
  _WORKFLOWANALYZERHOURS._serialized_start=383
  _WORKFLOWANALYZERHOURS._serialized_end=502
  _WORKFLOWANALYZERRESPONSE._serialized_start=504
  _WORKFLOWANALYZERRESPONSE._serialized_end=628
  _WORKFLOWANALYZERAPI._serialized_start=631
  _WORKFLOWANALYZERAPI._serialized_end=921
# @@protoc_insertion_point(module_scope)
