# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/team_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#fsai_grpc_api/protos/team_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a fsai_grpc_api/protos/utils.proto\"\xc4\x01\n\x04Team\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ndeleted_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x06 \x01(\x05\"(\n\x11\x43reateTeamRequest\x12\x13\n\x04team\x18\x01 \x01(\x0b\x32\x05.Team\"K\n\x12\x43reateTeamResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x13\n\x04team\x18\x02 \x01(\x0b\x32\x05.Team2@\n\x07TeamApi\x12\x35\n\nCreateTeam\x12\x12.CreateTeamRequest\x1a\x13.CreateTeamResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fsai_grpc_api.protos.team_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TEAM._serialized_start=107
  _TEAM._serialized_end=303
  _CREATETEAMREQUEST._serialized_start=305
  _CREATETEAMREQUEST._serialized_end=345
  _CREATETEAMRESPONSE._serialized_start=347
  _CREATETEAMRESPONSE._serialized_end=422
  _TEAMAPI._serialized_start=424
  _TEAMAPI._serialized_end=488
# @@protoc_insertion_point(module_scope)
