# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/review_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%fsai_grpc_api/protos/review_api.proto\":\n$GetNextReviewImageByMissionIdRequest\x12\x12\n\nmission_id\x18\x01 \x01(\x05\"9\n%GetNextReviewImageByMissionIdResponse\x12\x10\n\x08image_id\x18\x01 \x01(\x05\x32{\n\tReviewApi\x12n\n\x1dGetNextReviewImageByMissionId\x12%.GetNextReviewImageByMissionIdRequest\x1a&.GetNextReviewImageByMissionIdResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fsai_grpc_api.protos.review_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETNEXTREVIEWIMAGEBYMISSIONIDREQUEST._serialized_start=41
  _GETNEXTREVIEWIMAGEBYMISSIONIDREQUEST._serialized_end=99
  _GETNEXTREVIEWIMAGEBYMISSIONIDRESPONSE._serialized_start=101
  _GETNEXTREVIEWIMAGEBYMISSIONIDRESPONSE._serialized_end=158
  _REVIEWAPI._serialized_start=160
  _REVIEWAPI._serialized_end=283
# @@protoc_insertion_point(module_scope)
