# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/signed_url_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)fsai_grpc_api/protos/signed_url_api.proto\"\'\n\x13GetSignedUrlRequest\x12\x10\n\x08url_path\x18\x01 \x01(\t\"*\n\x14GetSignedUrlResponse\x12\x12\n\nsigned_url\x18\x01 \x01(\t\"`\n GetSignedMissionExportUrlRequest\x12\x13\n\x0bworkflow_id\x18\x01 \x01(\x05\x12\x14\n\x0cpackage_type\x18\x02 \x01(\t\x12\x11\n\tfile_type\x18\x03 \x01(\t\"7\n!GetSignedMissionExportUrlResponse\x12\x12\n\nsigned_url\x18\x01 \x01(\t2\xaf\x01\n\x0cSignedUrlApi\x12;\n\x0cGetSignedUrl\x12\x14.GetSignedUrlRequest\x1a\x15.GetSignedUrlResponse\x12\x62\n\x19GetSignedMissionExportUrl\x12!.GetSignedMissionExportUrlRequest\x1a\".GetSignedMissionExportUrlResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fsai_grpc_api.protos.signed_url_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETSIGNEDURLREQUEST._serialized_start=45
  _GETSIGNEDURLREQUEST._serialized_end=84
  _GETSIGNEDURLRESPONSE._serialized_start=86
  _GETSIGNEDURLRESPONSE._serialized_end=128
  _GETSIGNEDMISSIONEXPORTURLREQUEST._serialized_start=130
  _GETSIGNEDMISSIONEXPORTURLREQUEST._serialized_end=226
  _GETSIGNEDMISSIONEXPORTURLRESPONSE._serialized_start=228
  _GETSIGNEDMISSIONEXPORTURLRESPONSE._serialized_end=283
  _SIGNEDURLAPI._serialized_start=286
  _SIGNEDURLAPI._serialized_end=461
# @@protoc_insertion_point(module_scope)
