# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/team_member_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*fsai_grpc_api/protos/team_member_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a fsai_grpc_api/protos/utils.proto\"\xca\x01\n\nTeamMember\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0f\n\x07user_id\x18\x02 \x01(\x05\x12\x0f\n\x07team_id\x18\x03 \x01(\x05\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ndeleted_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"A\n\x1d\x46indOrCreateTeamMemberRequest\x12 \n\x0bteam_member\x18\x01 \x01(\x0b\x32\x0b.TeamMember\"d\n\x1e\x46indOrCreateTeamMemberResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12 \n\x0bteam_member\x18\x02 \x01(\x0b\x32\x0b.TeamMember2j\n\rTeamMemberApi\x12Y\n\x16\x46indOrCreateTeamMember\x12\x1e.FindOrCreateTeamMemberRequest\x1a\x1f.FindOrCreateTeamMemberResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fsai_grpc_api.protos.team_member_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TEAMMEMBER._serialized_start=114
  _TEAMMEMBER._serialized_end=316
  _FINDORCREATETEAMMEMBERREQUEST._serialized_start=318
  _FINDORCREATETEAMMEMBERREQUEST._serialized_end=383
  _FINDORCREATETEAMMEMBERRESPONSE._serialized_start=385
  _FINDORCREATETEAMMEMBERRESPONSE._serialized_end=485
  _TEAMMEMBERAPI._serialized_start=487
  _TEAMMEMBERAPI._serialized_end=593
# @@protoc_insertion_point(module_scope)
