# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/source_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%fsai_grpc_api/protos/source_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a fsai_grpc_api/protos/utils.proto\"\x90\x01\n\x06Source\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04slug\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"(\n\rSourceRequest\x12\x17\n\x06source\x18\x01 \x01(\x0b\x32\x07.Source\"K\n\x0eSourceResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x17\n\x06source\x18\x02 \x01(\x0b\x32\x07.Source2B\n\tSourceApi\x12\x35\n\x12\x46indOrCreateSource\x12\x0e.SourceRequest\x1a\x0f.SourceResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fsai_grpc_api.protos.source_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SOURCE._serialized_start=109
  _SOURCE._serialized_end=253
  _SOURCEREQUEST._serialized_start=255
  _SOURCEREQUEST._serialized_end=295
  _SOURCERESPONSE._serialized_start=297
  _SOURCERESPONSE._serialized_end=372
  _SOURCEAPI._serialized_start=374
  _SOURCEAPI._serialized_end=440
# @@protoc_insertion_point(module_scope)
