# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/user_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#fsai_grpc_api/protos/user_api.proto\x1a fsai_grpc_api/protos/utils.proto\">\n\x0bPermissions\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x65num\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"s\n\x04User\x12\n\n\x02id\x18\x01 \x01(\x05\x12\r\n\x05\x66irst\x18\x02 \x01(\t\x12\x0c\n\x04last\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x10\n\x08password\x18\x05 \x01(\t\x12!\n\x0bpermissions\x18\x06 \x03(\x0b\x32\x0c.Permissions\"(\n\x11\x43reateUserRequest\x12\x13\n\x04user\x18\x01 \x01(\x0b\x32\x05.User\"K\n\x12\x43reateUserResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x13\n\x04user\x18\x02 \x01(\x0b\x32\x05.User\"-\n\x16\x46indUserByEmailRequest\x12\x13\n\x04user\x18\x01 \x01(\x0b\x32\x05.User\"P\n\x17\x46indUserByEmailResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x13\n\x04user\x18\x02 \x01(\x0b\x32\x05.User\":\n\x17\x41uthenticateUserRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"K\n\x18\x41uthenticateUserResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\r\n\x05valid\x18\x02 \x01(\x08\x32\xcf\x01\n\x07UserApi\x12\x35\n\nCreateUser\x12\x12.CreateUserRequest\x1a\x13.CreateUserResponse\x12\x44\n\x0f\x46indUserByEmail\x12\x17.FindUserByEmailRequest\x1a\x18.FindUserByEmailResponse\x12G\n\x10\x41uthenticateUser\x12\x18.AuthenticateUserRequest\x1a\x19.AuthenticateUserResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fsai_grpc_api.protos.user_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PERMISSIONS._serialized_start=73
  _PERMISSIONS._serialized_end=135
  _USER._serialized_start=137
  _USER._serialized_end=252
  _CREATEUSERREQUEST._serialized_start=254
  _CREATEUSERREQUEST._serialized_end=294
  _CREATEUSERRESPONSE._serialized_start=296
  _CREATEUSERRESPONSE._serialized_end=371
  _FINDUSERBYEMAILREQUEST._serialized_start=373
  _FINDUSERBYEMAILREQUEST._serialized_end=418
  _FINDUSERBYEMAILRESPONSE._serialized_start=420
  _FINDUSERBYEMAILRESPONSE._serialized_end=500
  _AUTHENTICATEUSERREQUEST._serialized_start=502
  _AUTHENTICATEUSERREQUEST._serialized_end=560
  _AUTHENTICATEUSERRESPONSE._serialized_start=562
  _AUTHENTICATEUSERRESPONSE._serialized_end=637
  _USERAPI._serialized_start=640
  _USERAPI._serialized_end=847
# @@protoc_insertion_point(module_scope)
