# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/detection_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(fsai_grpc_api/protos/detection_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a fsai_grpc_api/protos/utils.proto\"\xaa\x01\n\tDetection\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x1c\n\tgeo_point\x18\x02 \x01(\x0b\x32\t.GeoPoint\x12\x13\n\x0b\x63\x61tegory_id\x18\x03 \x01(\x05\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"1\n\x10\x44\x65tectionRequest\x12\x1d\n\tdetection\x18\x01 \x01(\x0b\x32\n.Detection\"T\n\x11\x44\x65tectionResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1d\n\tdetection\x18\x02 \x01(\x0b\x32\n.Detection\"^\n\x12\x44\x65tectionResponses\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12&\n\ndetections\x18\x02 \x03(\x0b\x32\x12.DetectionResponse2N\n\x0c\x44\x65tectionApi\x12>\n\x15\x46indOrCreateDetection\x12\x11.DetectionRequest\x1a\x12.DetectionResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fsai_grpc_api.protos.detection_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DETECTION._serialized_start=112
  _DETECTION._serialized_end=282
  _DETECTIONREQUEST._serialized_start=284
  _DETECTIONREQUEST._serialized_end=333
  _DETECTIONRESPONSE._serialized_start=335
  _DETECTIONRESPONSE._serialized_end=419
  _DETECTIONRESPONSES._serialized_start=421
  _DETECTIONRESPONSES._serialized_end=515
  _DETECTIONAPI._serialized_start=517
  _DETECTIONAPI._serialized_end=595
# @@protoc_insertion_point(module_scope)
